@@ -79,7 +79,7 @@ BEGIN {
 }
 
 
-$VERSION = "1.03";
+$VERSION = "1.04";
 
 our $DEBUG = 0;
 my %STARTEDCHILD = ();
@@ -1911,18 +1911,13 @@ hero is coming along and will fix this, but this is probably not me ;-)
 
 Sorry for that.
 
-=head1 LICENSE
+=head1 AUTHORS
 
-Copyright 1999-2011 Roland Huss.
+Roland Huß <roland@consol.de>
 
-This library is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
+Currently maintained by Nicholas Hubbard <nicholashubbard@posteo.net>
 
-=head1 AUTHOR
-
-... roland
-
-=head1 Contributors
+=head1 CONTRIBUTORS
 
 =over 4
 
@@ -1932,10 +1927,59 @@ Alexandr Ciornii <alexchorny@gmail.com>
 
 =item *
 
+Andrew Danforth
+
+=item *
+
+Andy Ford
+
+=item *
+
+Bray Jones
+
+=item *
+
+Clinton Gormley
+
+=item *
+
+Eric Wilhelm
+
+=item *
+
+Frank Mayer
+
+=item *
+
+Jamie McCarthy
+
+=item *
+
+Loic Paillotin
+
+=item *
+
 Nicholas Hubbard <nicholashubbard@posteo.net>
 
+=item *
+
+Peter Vary
+
+=item *
+
+Philippe Verdret
+
 =back
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) 1999-2013 Roland Huß.
+
+Copyright (c) 2022 Nicholas Hubbard.
+
+This library is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
 =cut
 
 1;
